@@ -17,12 +17,11 @@
 
 from django import template
 
-from Zephyrus.blog_extension.models import ViewCount as ViewCountModel
-
 register = template.Library()
 
 # FIXME: 不知為何使用 {% allCategoryRoots categories %} 會在畫面上 render 出字來，
 # 先暫時 return 空字串避免畫面 render 出不必要的字，然後使用 context 回傳值
+
 @register.simple_tag(takes_context=True)
 def allCategoryRoots(context, categories):
     roots = []
@@ -31,7 +30,7 @@ def allCategoryRoots(context, categories):
         root = category.get_root()
         if not root in roots:
             roots.append(root)
-            
+           
         parent = category
         while parent:
             if not parent in parents:
@@ -40,24 +39,3 @@ def allCategoryRoots(context, categories):
     context['roots'] = roots
     context['parents'] = parents
     return ''
-
-@register.simple_tag(takes_context=True)
-def viewCount(context, url=None):
-    request = context['request']
-    if url:
-        if not url.startswith('http'): 
-            url = request.build_absolute_uri('/')[:-1].strip("/") + url
-        
-        obj, created = ViewCountModel.objects.get_or_create(
-            url=url,
-        )
-    else:
-        url = request.build_absolute_uri(request.path)
-        obj, created = ViewCountModel.objects.get_or_create(
-            url=url,
-        )
-        obj.count += 1
-        obj.save()
-    
-    return obj.count
-    
\ No newline at end of file
