@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate2.py 11654 2019-07-17 20:42:48Z Lavender $
+# $Id: build_boilerplate2.py 11671 2019-08-07 04:50:27Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-07-18 04:42:48 +0800 (週四, 18 七月 2019) $
-# $Revision: 11654 $
+# $Date: 2019-08-07 12:50:27 +0800 (週三, 07 八月 2019) $
+# $Revision: 11671 $
 
 import os
 import re
@@ -575,7 +575,8 @@ class Command(BaseCommand):
                 value = tag.get(key)
                 if value:
                     value = value.replace('\\', '/')  
-                    # "./images/g2.jpg" "images/g2.jpg" 統一
+                    # "./images/g2.jpg" "../images/g2.jpg" "images/g2.jpg" 統一
+                    value = value.replace('../', '')
                     value = value.replace('./', '')
                     
                     if (not value in fileDict and 
@@ -604,6 +605,9 @@ class Command(BaseCommand):
                     continue
                 for path in fileDict:
                     value = value.replace('\\', '/')
+                    # "../images/g2.jpg" 處理成 "images/g2.jpg"
+                    value = value.replace('../', '')
+                    
                     # 考慮到有時 attr 的 value 可能不只 static 路徑，
                     # 像是attr="return func('static')"等等，所以才用現在的方式
 
