@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11643 2019-06-28 14:14:33Z Andy $
+# $Id: views.py 11785 2019-12-01 11:40:04Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,16 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-06-28 22:14:33 +0800 (週五, 28 六月 2019) $
-# $Revision: 11643 $
+# $Date: 2019-12-01 19:40:04 +0800 (週日, 01 十二月 2019) $
+# $Revision: 11785 $
 
 import datetime
 import logging
 import urllib
 import six
 
+from unidecode import unidecode
+
 from django.shortcuts import redirect, get_object_or_404
 from django.views.generic import View
 from django.core.mail import send_mail
@@ -61,7 +63,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
         
         dataDict = {}
         for field in order:
-            key = slugify(field.label)
+            key = slugify(unidecode(field.label).replace('-', '_'))
             value = form.cleaned_data.get(key, '(no input)')
             dataDict[key] = {'value': value, 'field': field,}
     elif formId:
